### Discription
A pakage that contains following modules
<Ul>
    <li>AreaOfshape contains give area of different shapes .</li>
    <li>A calculator.</li>
    <li>LMC Module.</li>
    <li>function that check prime numbers.</li>
    <li>function that check even or odd numbers</li>
    <li>A program Remove all consonants from string</li>
    <li>A program swaps the 1st and last elements of a list</li> </ul>
